"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.baseAxiosResponseErrorInterceptor = exports.baseAxiosResponseInterceptor = exports.baseAxiosRequestErrorInterceptor = exports.baseAxiosRequestInterceptor = exports.baseAxiosConfig = void 0;
var rotating_file_stream_1 = require("rotating-file-stream");
var path_1 = require("path");
var qs_1 = require("qs");
var debug_helper_1 = __importDefault(require("./util/debug_helper"));
var logError = debug_helper_1.default(__filename).logError;
var baseAxiosConfig = {
    timeout: 10000,
    headers: {
        'User-Agent': 'ts-crypto-cli',
        'content-type': 'application/x-www-form-urlencoded',
    }
};
exports.baseAxiosConfig = baseAxiosConfig;
var TS_CRYPTO_CLI_LOGS_PATH = process.env.TS_CRYPTO_CLI_LOGS_PATH;
var dirPath = TS_CRYPTO_CLI_LOGS_PATH ? path_1.resolve(TS_CRYPTO_CLI_LOGS_PATH) : null;
// Rotating filenames
var calculateFileName = function (date, index) {
    var _a = new Date().toISOString().slice(0, 7).split('-'), YYYY = _a[0], MM = _a[1];
    var fileName = "ts-crypto-cli_" + YYYY + "_" + MM;
    if (!date)
        return fileName + ".csv";
    return fileName + "_" + index + ".csv";
};
var stream = dirPath ? rotating_file_stream_1.createStream(calculateFileName, {
    size: '100M',
    interval: '1M',
    path: dirPath,
    immutable: true,
}) : null;
var baseAxiosRequestInterceptor = function (config) {
    if (['PUT', 'POST', 'PATCH'].includes(config.method.toUpperCase())) {
        delete config.params;
        config.data = qs_1.stringify(config.data);
    }
    else {
        delete config.data;
    }
    var method = config.method, baseURL = config.baseURL, url = config.url, _a = config.params, params = _a === void 0 ? '-' : _a, _b = config.data, data = _b === void 0 ? '-' : _b;
    if (stream) {
        stream.write("\n" + new Date().toISOString() + "; " + method.toUpperCase() + "; " + baseURL + (baseURL.endsWith('/') || url.startsWith('/') ? '' : '/') + url + "; " + params + "; " + data + "; -; -; -");
    }
    return config;
};
exports.baseAxiosRequestInterceptor = baseAxiosRequestInterceptor;
var baseAxiosResponseInterceptor = function (response) {
    var _a = response.config, method = _a.method, baseURL = _a.baseURL, url = _a.url, _b = _a.params, params = _b === void 0 ? '-' : _b, _c = response.status, status = _c === void 0 ? null : _c, _d = response.statusText, statusText = _d === void 0 ? '-' : _d, _e = response.data, data = _e === void 0 ? '-' : _e;
    if (stream) {
        stream.write("\n" + new Date().toISOString() + "; " + method.toUpperCase() + "; " + baseURL + (baseURL.endsWith('/') || url.startsWith('/') ? '' : '/') + url + "; " + params + "; " + typeof data + "; " + status + "; " + statusText + "; -");
    }
    return response;
};
exports.baseAxiosResponseInterceptor = baseAxiosResponseInterceptor;
var baseAxiosRequestErrorInterceptor = function (axiosRequestError) {
    var _a = axiosRequestError.config, method = _a.method, baseURL = _a.baseURL, url = _a.url, _b = _a.params, params = _b === void 0 ? '-' : _b, _c = _a.data, data = _c === void 0 ? '-' : _c, _d = axiosRequestError.code, code = _d === void 0 ? '-' : _d, _e = axiosRequestError.response, _f = _e.status, status = _f === void 0 ? null : _f, _g = _e.statusText, statusText = _g === void 0 ? '-' : _g;
    if (stream) {
        stream.write("\n" + new Date().toISOString() + "; " + method.toUpperCase() + "; " + baseURL + (baseURL.endsWith('/') || url.startsWith('/') ? '' : '/') + url + "; " + params + "; " + JSON.stringify(data) + "; " + status + "; " + statusText + "; " + code);
    }
    logError({ axiosRequestError: axiosRequestError });
    throw axiosRequestError;
};
exports.baseAxiosRequestErrorInterceptor = baseAxiosRequestErrorInterceptor;
var baseAxiosResponseErrorInterceptor = function (axiosResponseError) {
    var _a = axiosResponseError.config, method = _a.method, baseURL = _a.baseURL, url = _a.url, _b = _a.params, params = _b === void 0 ? '-' : _b, _c = _a.data, data = _c === void 0 ? '-' : _c, _d = axiosResponseError.code, code = _d === void 0 ? '-' : _d, _e = axiosResponseError.response, _f = _e.status, status = _f === void 0 ? null : _f, _g = _e.statusText, statusText = _g === void 0 ? '-' : _g;
    if (stream) {
        stream.write("\n" + new Date().toISOString() + "; " + method.toUpperCase() + "; " + baseURL + (baseURL.endsWith('/') || url.startsWith('/') ? '' : '/') + url + "; " + params + "; " + typeof data + "; " + status + "; " + statusText + "; " + code);
    }
    logError({ axiosResponseError: axiosResponseError });
    throw axiosResponseError;
};
exports.baseAxiosResponseErrorInterceptor = baseAxiosResponseErrorInterceptor;
